@@ -79,14 +79,15 @@ class Client(object):
         substance_names : list
             List of names (strings) of each substance to be looked up.
         descriptor_set : str
-            Specifies a descriptor subset (for 'molecular' featurization only). 
-            By default, all descriptors are returned.
-            The most common choices are 'all' or 'universal'.
+            Specifies a descriptor subset. 
+            By default, all available descriptors are returned.
+            The most common choices are 'all' or 'rdkit_universal'.
             The 'all' descriptor set includes all available descriptors.
-            The 'universal' descriptor set includes only those descriptors
-            that are real-valued across most or all available substances.
-            To see all available descriptor sets,
-            log in by web browser and featurize a model.
+            The 'rdkit_universal' descriptor set includes only rdkit descriptors
+            that are real-valued across most available substances.
+            To see all available descriptor sets, log in by web browser
+            and examine the featurization step of a modeling pipeline.
+            
 
         Returns
         -------
@@ -131,10 +132,11 @@ class Client(object):
         ----------
         featurization : str
             Specifies which featurization to apply. 
-            This should be 'lithium_ionic' or 'molecular'.
-            In the current version, the 'molecular' option is not supported.
+            This should be 'lithium_ionic', 'transition_metal_redox', or 'molecular'.
+            The 'molecular' and 'transition_metal_redox' options are disabled by default 
+            (only specific instances of the application are allowed to use them).
         file_paths : dict 
-            Dist of file paths containing substance data.
+            Dict of file paths containing substance data.
             Each path is opened and uploaded to Aionics.
             The keys of this dict are used to index
             the returned table of descriptors.
@@ -784,8 +786,8 @@ class Client(object):
             how substances in the column are to be featurized.
             Each substance can have the following settings:
 
-            - 'featurization' (str): Specifies which featurization to apply. Either 'lithium_ionic' or 'molecular'.
-            - 'descriptor_set' (str): See `get_descriptors()`.
+            - 'featurization' (bool): Specifies whether or not the substance should be featurized. 
+            - 'descriptor_set' (str): Descriptor subset (optional). See `get_descriptors()`.
             - 'concentration_weighted' (bool): Optional, default False. Multiplies the descriptors by substance concentrations. For a column named 'substance1', the concentration data is assumed to be in a column named 'substance1_conc'.
             - 'in_solution' (bool): Optional, default False. Substances in solution get their descriptors combined additively with the descriptors of other substances in the same solution.
             - 'solution_name' (str): If in_solution, specifies which solution the substance is in.
